@@ -79,6 +79,14 @@ class Auth:
             verbose=self.gaia.verbose,
         )
 
+    def slack_user(self):
+        """Return an authorized Slack Workspace instance with a user token."""
+        from bits.slack import Slack
+        settings = self.gaia.get_settings("slack_broadinstitute")
+        return Slack(
+            token=self.gaia.get_secret(settings.get("user_token_name")),
+        )
+
     def space_mysql(self):
         """Return an authorized MySQL instance for Space."""
         from bits.mysql import MySQL
